# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.3.0~4d1ca3f',
    built_at='2024-02-06 04:49:54Z',
    sha='4d1ca3fde2601aaaeb733072bdcc0f752307e19d',
    branch='HEAD',
    tag='v4.3.0',
)
